"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const construct_1 = __importDefault(require("./construct"));
const language_1 = require("../enums/language");
const language_2 = require("./language");
const shelljs_1 = require("shelljs");
class Compiler {
    constructor() {
        this.languages = language_1.Language;
        (0, construct_1.default)();
    }
    compile({ language, code, input, timeout, similarWorkingJobCount, afterRunTest }) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { id, start_date } = yield language_2.Languages[language].Run({
                    code,
                    input: input || "",
                    timeout,
                    similarWorkingJobCount: similarWorkingJobCount || 1,
                    afterRunTest
                });
                const options = {};
                if (timeout) {
                    options.timeout = timeout;
                }
                const proccess = (0, shelljs_1.exec)(`tsp -c ${id}`, options);
                if (!(proccess === null || proccess === void 0 ? void 0 : proccess.stderr) && proccess.stdout) {
                    proccess.exec(`tsp -k ${id}`, options);
                    return {
                        data: proccess.stdout,
                        start_date,
                    };
                }
                if ((proccess === null || proccess === void 0 ? void 0 : proccess.stderr) &&
                    (proccess === null || proccess === void 0 ? void 0 : proccess.code) === 255 &&
                    ((_a = proccess === null || proccess === void 0 ? void 0 : proccess.stderr) === null || _a === void 0 ? void 0 : _a.includes("Error in the request: Job"))) {
                    return {
                        warning: 'Please try again',
                    };
                }
                return {
                    data: proccess.stdout || "",
                    start_date,
                };
            }
            catch (e) {
                return {
                    error: (e === null || e === void 0 ? void 0 : e.message) || "Inital Server Error",
                };
            }
        });
    }
    getLanguages() {
        return [
            {
                key: 'javascript',
                value: this.languages.Node,
                label: '(Node Js) Javascript',
                ext: 'js',
                input: false,
            },
            {
                key: 'cpp',
                value: this.languages['C++'],
                label: this.languages['C++'],
                ext: 'cpp',
                input: true,
            },
            {
                key: 'c',
                value: this.languages.C,
                label: this.languages.C,
                ext: 'c',
                input: true,
            },
            {
                key: 'java',
                value: this.languages.Java,
                label: this.languages.Java,
                ext: 'java',
                input: true,
            },
        ];
    }
}
exports.default = Compiler;
